Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the experimental v1alpha1 API group +kubebuilder:object:generate=true +groupName=experimental.kubeblocks.io
Index ¶
Constants ¶
const ( // ReasonNotReady is a reason for condition ScaleReady. ReasonNotReady = "NotReady" // ReasonReady is a reason for condition ScaleReady. ReasonReady = "Ready" )
Variables ¶
var ( // GroupVersion is group version used to register these objects GroupVersion = schema.GroupVersion{Group: "experimental.kubeblocks.io", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ComponentStatus ¶
type ComponentStatus struct {
// Specified the Component name.
Name string `json:"name"`
// The current number of instances of this component.
CurrentReplicas int32 `json:"currentReplicas"`
// The number of instances of this component with a Ready condition.
ReadyReplicas int32 `json:"readyReplicas"`
// The number of instances of this component with a Ready condition for at least MinReadySeconds defined in the instance template.
AvailableReplicas int32 `json:"availableReplicas"`
// The desired number of instances of this component.
// Usually, it should be the number of nodes.
DesiredReplicas int32 `json:"desiredReplicas"`
}
func (*ComponentStatus) DeepCopy ¶
func (in *ComponentStatus) DeepCopy() *ComponentStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ComponentStatus.
func (*ComponentStatus) DeepCopyInto ¶
func (in *ComponentStatus) DeepCopyInto(out *ComponentStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ConditionType ¶
type ConditionType string
const ( // ScaleReady is added to a nodecountscaler when all target components are ready. ScaleReady ConditionType = "ScaleReady" )
type NodeCountScaler ¶
type NodeCountScaler struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec NodeCountScalerSpec `json:"spec,omitempty"`
Status NodeCountScalerStatus `json:"status,omitempty"`
}
NodeCountScaler is the Schema for the nodecountscalers API
func (*NodeCountScaler) DeepCopy ¶
func (in *NodeCountScaler) DeepCopy() *NodeCountScaler
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeCountScaler.
func (*NodeCountScaler) DeepCopyInto ¶
func (in *NodeCountScaler) DeepCopyInto(out *NodeCountScaler)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NodeCountScaler) DeepCopyObject ¶
func (in *NodeCountScaler) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NodeCountScalerList ¶
type NodeCountScalerList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []NodeCountScaler `json:"items"`
}
NodeCountScalerList contains a list of NodeCountScaler
func (*NodeCountScalerList) DeepCopy ¶
func (in *NodeCountScalerList) DeepCopy() *NodeCountScalerList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeCountScalerList.
func (*NodeCountScalerList) DeepCopyInto ¶
func (in *NodeCountScalerList) DeepCopyInto(out *NodeCountScalerList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NodeCountScalerList) DeepCopyObject ¶
func (in *NodeCountScalerList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NodeCountScalerSpec ¶
type NodeCountScalerSpec struct {
// Specified the target Cluster name this scaler applies to.
TargetClusterName string `json:"targetClusterName"`
// Specified the target Component names this scaler applies to.
// All Components will be applied if not set.
//
// +optional
TargetComponentNames []string `json:"targetComponentNames,omitempty"`
}
NodeCountScalerSpec defines the desired state of NodeCountScaler
func (*NodeCountScalerSpec) DeepCopy ¶
func (in *NodeCountScalerSpec) DeepCopy() *NodeCountScalerSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeCountScalerSpec.
func (*NodeCountScalerSpec) DeepCopyInto ¶
func (in *NodeCountScalerSpec) DeepCopyInto(out *NodeCountScalerSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type NodeCountScalerStatus ¶
type NodeCountScalerStatus struct {
// Records the current status information of all Components specified in the NodeCountScalerSpec.
//
// +optional
ComponentStatuses []ComponentStatus `json:"componentStatuses,omitempty"`
// Represents the latest available observations of a nodecountscaler's current state.
// Known .status.conditions.type are: "ScaleReady".
// ScaleReady - All target components are ready.
//
// +optional
// +patchMergeKey=type
// +patchStrategy=merge
// +listType=map
// +listMapKey=type
Conditions []metav1.Condition `json:"conditions,omitempty" patchStrategy:"merge" patchMergeKey:"type"`
// LastScaleTime is the last time the NodeCountScaler scaled the number of instances.
//
// +optional
LastScaleTime metav1.Time `json:"lastScaleTime,omitempty"`
}
NodeCountScalerStatus defines the observed state of NodeCountScaler
func (*NodeCountScalerStatus) DeepCopy ¶
func (in *NodeCountScalerStatus) DeepCopy() *NodeCountScalerStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NodeCountScalerStatus.
func (*NodeCountScalerStatus) DeepCopyInto ¶
func (in *NodeCountScalerStatus) DeepCopyInto(out *NodeCountScalerStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.