Documentation
¶
Index ¶
- func NewBackupPolicyTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewComponentClassDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewComponentResourceConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBackupPolicyTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredComponentClassDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredComponentResourceConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredOpsRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredServiceDescriptorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewOpsRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewServiceDescriptorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type BackupPolicyTemplateInformer
- type ClusterDefinitionInformer
- type ClusterInformer
- type ClusterVersionInformer
- type ComponentClassDefinitionInformer
- type ComponentResourceConstraintInformer
- type ConfigConstraintInformer
- type Interface
- type OpsRequestInformer
- type ServiceDescriptorInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBackupPolicyTemplateInformer ¶
func NewBackupPolicyTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBackupPolicyTemplateInformer constructs a new informer for BackupPolicyTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterDefinitionInformer ¶
func NewClusterDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterDefinitionInformer constructs a new informer for ClusterDefinition type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterInformer ¶
func NewClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterInformer constructs a new informer for Cluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterVersionInformer ¶
func NewClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterVersionInformer constructs a new informer for ClusterVersion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewComponentClassDefinitionInformer ¶
func NewComponentClassDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewComponentClassDefinitionInformer constructs a new informer for ComponentClassDefinition type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewComponentResourceConstraintInformer ¶
func NewComponentResourceConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewComponentResourceConstraintInformer constructs a new informer for ComponentResourceConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewConfigConstraintInformer ¶
func NewConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewConfigConstraintInformer constructs a new informer for ConfigConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBackupPolicyTemplateInformer ¶
func NewFilteredBackupPolicyTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBackupPolicyTemplateInformer constructs a new informer for BackupPolicyTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterDefinitionInformer ¶
func NewFilteredClusterDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterDefinitionInformer constructs a new informer for ClusterDefinition type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterInformer ¶
func NewFilteredClusterInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterInformer constructs a new informer for Cluster type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterVersionInformer ¶
func NewFilteredClusterVersionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterVersionInformer constructs a new informer for ClusterVersion type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredComponentClassDefinitionInformer ¶
func NewFilteredComponentClassDefinitionInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredComponentClassDefinitionInformer constructs a new informer for ComponentClassDefinition type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredComponentResourceConstraintInformer ¶
func NewFilteredComponentResourceConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredComponentResourceConstraintInformer constructs a new informer for ComponentResourceConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredConfigConstraintInformer ¶
func NewFilteredConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredConfigConstraintInformer constructs a new informer for ConfigConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredOpsRequestInformer ¶
func NewFilteredOpsRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredOpsRequestInformer constructs a new informer for OpsRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredServiceDescriptorInformer ¶ added in v0.7.0
func NewFilteredServiceDescriptorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredServiceDescriptorInformer constructs a new informer for ServiceDescriptor type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewOpsRequestInformer ¶
func NewOpsRequestInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewOpsRequestInformer constructs a new informer for OpsRequest type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewServiceDescriptorInformer ¶ added in v0.7.0
func NewServiceDescriptorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewServiceDescriptorInformer constructs a new informer for ServiceDescriptor type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type BackupPolicyTemplateInformer ¶
type BackupPolicyTemplateInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.BackupPolicyTemplateLister
}
BackupPolicyTemplateInformer provides access to a shared informer and lister for BackupPolicyTemplates.
type ClusterDefinitionInformer ¶
type ClusterDefinitionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterDefinitionLister
}
ClusterDefinitionInformer provides access to a shared informer and lister for ClusterDefinitions.
type ClusterInformer ¶
type ClusterInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterLister
}
ClusterInformer provides access to a shared informer and lister for Clusters.
type ClusterVersionInformer ¶
type ClusterVersionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterVersionLister
}
ClusterVersionInformer provides access to a shared informer and lister for ClusterVersions.
type ComponentClassDefinitionInformer ¶
type ComponentClassDefinitionInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ComponentClassDefinitionLister
}
ComponentClassDefinitionInformer provides access to a shared informer and lister for ComponentClassDefinitions.
type ComponentResourceConstraintInformer ¶
type ComponentResourceConstraintInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ComponentResourceConstraintLister
}
ComponentResourceConstraintInformer provides access to a shared informer and lister for ComponentResourceConstraints.
type ConfigConstraintInformer ¶
type ConfigConstraintInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ConfigConstraintLister
}
ConfigConstraintInformer provides access to a shared informer and lister for ConfigConstraints.
type Interface ¶
type Interface interface {
// BackupPolicyTemplates returns a BackupPolicyTemplateInformer.
BackupPolicyTemplates() BackupPolicyTemplateInformer
// Clusters returns a ClusterInformer.
Clusters() ClusterInformer
// ClusterDefinitions returns a ClusterDefinitionInformer.
ClusterDefinitions() ClusterDefinitionInformer
// ClusterVersions returns a ClusterVersionInformer.
ClusterVersions() ClusterVersionInformer
// ComponentClassDefinitions returns a ComponentClassDefinitionInformer.
ComponentClassDefinitions() ComponentClassDefinitionInformer
// ComponentResourceConstraints returns a ComponentResourceConstraintInformer.
ComponentResourceConstraints() ComponentResourceConstraintInformer
// ConfigConstraints returns a ConfigConstraintInformer.
ConfigConstraints() ConfigConstraintInformer
// OpsRequests returns a OpsRequestInformer.
OpsRequests() OpsRequestInformer
// ServiceDescriptors returns a ServiceDescriptorInformer.
ServiceDescriptors() ServiceDescriptorInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type OpsRequestInformer ¶
type OpsRequestInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.OpsRequestLister
}
OpsRequestInformer provides access to a shared informer and lister for OpsRequests.
type ServiceDescriptorInformer ¶ added in v0.7.0
type ServiceDescriptorInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ServiceDescriptorLister
}
ServiceDescriptorInformer provides access to a shared informer and lister for ServiceDescriptors.