Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewConfigConstraintInformer ¶
func NewConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewConfigConstraintInformer constructs a new informer for ConfigConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredConfigConstraintInformer ¶
func NewFilteredConfigConstraintInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredConfigConstraintInformer constructs a new informer for ConfigConstraint type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ConfigConstraintInformer ¶
type ConfigConstraintInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.ConfigConstraintLister
}
ConfigConstraintInformer provides access to a shared informer and lister for ConfigConstraints.
type Interface ¶
type Interface interface {
// ConfigConstraints returns a ConfigConstraintInformer.
ConfigConstraints() ConfigConstraintInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.