Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAddonInformer ¶
func NewAddonInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewAddonInformer constructs a new informer for Addon type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredAddonInformer ¶
func NewFilteredAddonInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredAddonInformer constructs a new informer for Addon type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type AddonInformer ¶
type AddonInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.AddonLister
}
AddonInformer provides access to a shared informer and lister for Addons.
type Interface ¶
type Interface interface {
// Addons returns a AddonInformer.
Addons() AddonInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
Click to show internal directories.
Click to hide internal directories.