Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredStorageProviderInformer ¶
func NewFilteredStorageProviderInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredStorageProviderInformer constructs a new informer for StorageProvider type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewStorageProviderInformer ¶
func NewStorageProviderInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewStorageProviderInformer constructs a new informer for StorageProvider type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// StorageProviders returns a StorageProviderInformer.
StorageProviders() StorageProviderInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type StorageProviderInformer ¶
type StorageProviderInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.StorageProviderLister
}
StorageProviderInformer provides access to a shared informer and lister for StorageProviders.