Documentation
¶
Index ¶
- type BackupPolicyTemplateLister
- type BackupPolicyTemplateListerExpansion
- type ClusterDefinitionLister
- type ClusterDefinitionListerExpansion
- type ClusterLister
- type ClusterListerExpansion
- type ClusterNamespaceLister
- type ClusterNamespaceListerExpansion
- type ClusterVersionLister
- type ClusterVersionListerExpansion
- type ComponentClassDefinitionLister
- type ComponentClassDefinitionListerExpansion
- type ComponentDefinitionLister
- type ComponentDefinitionListerExpansion
- type ComponentLister
- type ComponentListerExpansion
- type ComponentNamespaceLister
- type ComponentNamespaceListerExpansion
- type ComponentResourceConstraintLister
- type ComponentResourceConstraintListerExpansion
- type ComponentVersionLister
- type ComponentVersionListerExpansion
- type ConfigConstraintLister
- type ConfigConstraintListerExpansion
- type OpsDefinitionLister
- type OpsDefinitionListerExpansion
- type OpsRequestLister
- type OpsRequestListerExpansion
- type OpsRequestNamespaceLister
- type OpsRequestNamespaceListerExpansion
- type ServiceDescriptorLister
- type ServiceDescriptorListerExpansion
- type ServiceDescriptorNamespaceLister
- type ServiceDescriptorNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BackupPolicyTemplateLister ¶
type BackupPolicyTemplateLister interface {
// List lists all BackupPolicyTemplates in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.BackupPolicyTemplate, err error)
// Get retrieves the BackupPolicyTemplate from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.BackupPolicyTemplate, error)
BackupPolicyTemplateListerExpansion
}
BackupPolicyTemplateLister helps list BackupPolicyTemplates. All objects returned here must be treated as read-only.
func NewBackupPolicyTemplateLister ¶
func NewBackupPolicyTemplateLister(indexer cache.Indexer) BackupPolicyTemplateLister
NewBackupPolicyTemplateLister returns a new BackupPolicyTemplateLister.
type BackupPolicyTemplateListerExpansion ¶
type BackupPolicyTemplateListerExpansion interface{}
BackupPolicyTemplateListerExpansion allows custom methods to be added to BackupPolicyTemplateLister.
type ClusterDefinitionLister ¶
type ClusterDefinitionLister interface {
// List lists all ClusterDefinitions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterDefinition, err error)
// Get retrieves the ClusterDefinition from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ClusterDefinition, error)
ClusterDefinitionListerExpansion
}
ClusterDefinitionLister helps list ClusterDefinitions. All objects returned here must be treated as read-only.
func NewClusterDefinitionLister ¶
func NewClusterDefinitionLister(indexer cache.Indexer) ClusterDefinitionLister
NewClusterDefinitionLister returns a new ClusterDefinitionLister.
type ClusterDefinitionListerExpansion ¶
type ClusterDefinitionListerExpansion interface{}
ClusterDefinitionListerExpansion allows custom methods to be added to ClusterDefinitionLister.
type ClusterLister ¶
type ClusterLister interface {
// List lists all Clusters in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Cluster, err error)
// Clusters returns an object that can list and get Clusters.
Clusters(namespace string) ClusterNamespaceLister
ClusterListerExpansion
}
ClusterLister helps list Clusters. All objects returned here must be treated as read-only.
func NewClusterLister ¶
func NewClusterLister(indexer cache.Indexer) ClusterLister
NewClusterLister returns a new ClusterLister.
type ClusterListerExpansion ¶
type ClusterListerExpansion interface{}
ClusterListerExpansion allows custom methods to be added to ClusterLister.
type ClusterNamespaceLister ¶
type ClusterNamespaceLister interface {
// List lists all Clusters in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Cluster, err error)
// Get retrieves the Cluster from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Cluster, error)
ClusterNamespaceListerExpansion
}
ClusterNamespaceLister helps list and get Clusters. All objects returned here must be treated as read-only.
type ClusterNamespaceListerExpansion ¶
type ClusterNamespaceListerExpansion interface{}
ClusterNamespaceListerExpansion allows custom methods to be added to ClusterNamespaceLister.
type ClusterVersionLister ¶
type ClusterVersionLister interface {
// List lists all ClusterVersions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ClusterVersion, err error)
// Get retrieves the ClusterVersion from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ClusterVersion, error)
ClusterVersionListerExpansion
}
ClusterVersionLister helps list ClusterVersions. All objects returned here must be treated as read-only.
func NewClusterVersionLister ¶
func NewClusterVersionLister(indexer cache.Indexer) ClusterVersionLister
NewClusterVersionLister returns a new ClusterVersionLister.
type ClusterVersionListerExpansion ¶
type ClusterVersionListerExpansion interface{}
ClusterVersionListerExpansion allows custom methods to be added to ClusterVersionLister.
type ComponentClassDefinitionLister ¶
type ComponentClassDefinitionLister interface {
// List lists all ComponentClassDefinitions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ComponentClassDefinition, err error)
// Get retrieves the ComponentClassDefinition from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ComponentClassDefinition, error)
ComponentClassDefinitionListerExpansion
}
ComponentClassDefinitionLister helps list ComponentClassDefinitions. All objects returned here must be treated as read-only.
func NewComponentClassDefinitionLister ¶
func NewComponentClassDefinitionLister(indexer cache.Indexer) ComponentClassDefinitionLister
NewComponentClassDefinitionLister returns a new ComponentClassDefinitionLister.
type ComponentClassDefinitionListerExpansion ¶
type ComponentClassDefinitionListerExpansion interface{}
ComponentClassDefinitionListerExpansion allows custom methods to be added to ComponentClassDefinitionLister.
type ComponentDefinitionLister ¶ added in v0.8.0
type ComponentDefinitionLister interface {
// List lists all ComponentDefinitions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ComponentDefinition, err error)
// Get retrieves the ComponentDefinition from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ComponentDefinition, error)
ComponentDefinitionListerExpansion
}
ComponentDefinitionLister helps list ComponentDefinitions. All objects returned here must be treated as read-only.
func NewComponentDefinitionLister ¶ added in v0.8.0
func NewComponentDefinitionLister(indexer cache.Indexer) ComponentDefinitionLister
NewComponentDefinitionLister returns a new ComponentDefinitionLister.
type ComponentDefinitionListerExpansion ¶ added in v0.8.0
type ComponentDefinitionListerExpansion interface{}
ComponentDefinitionListerExpansion allows custom methods to be added to ComponentDefinitionLister.
type ComponentLister ¶ added in v0.8.0
type ComponentLister interface {
// List lists all Components in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Component, err error)
// Components returns an object that can list and get Components.
Components(namespace string) ComponentNamespaceLister
ComponentListerExpansion
}
ComponentLister helps list Components. All objects returned here must be treated as read-only.
func NewComponentLister ¶ added in v0.8.0
func NewComponentLister(indexer cache.Indexer) ComponentLister
NewComponentLister returns a new ComponentLister.
type ComponentListerExpansion ¶ added in v0.8.0
type ComponentListerExpansion interface{}
ComponentListerExpansion allows custom methods to be added to ComponentLister.
type ComponentNamespaceLister ¶ added in v0.8.0
type ComponentNamespaceLister interface {
// List lists all Components in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Component, err error)
// Get retrieves the Component from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Component, error)
ComponentNamespaceListerExpansion
}
ComponentNamespaceLister helps list and get Components. All objects returned here must be treated as read-only.
type ComponentNamespaceListerExpansion ¶ added in v0.8.0
type ComponentNamespaceListerExpansion interface{}
ComponentNamespaceListerExpansion allows custom methods to be added to ComponentNamespaceLister.
type ComponentResourceConstraintLister ¶
type ComponentResourceConstraintLister interface {
// List lists all ComponentResourceConstraints in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ComponentResourceConstraint, err error)
// Get retrieves the ComponentResourceConstraint from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ComponentResourceConstraint, error)
ComponentResourceConstraintListerExpansion
}
ComponentResourceConstraintLister helps list ComponentResourceConstraints. All objects returned here must be treated as read-only.
func NewComponentResourceConstraintLister ¶
func NewComponentResourceConstraintLister(indexer cache.Indexer) ComponentResourceConstraintLister
NewComponentResourceConstraintLister returns a new ComponentResourceConstraintLister.
type ComponentResourceConstraintListerExpansion ¶
type ComponentResourceConstraintListerExpansion interface{}
ComponentResourceConstraintListerExpansion allows custom methods to be added to ComponentResourceConstraintLister.
type ComponentVersionLister ¶ added in v0.9.0
type ComponentVersionLister interface {
// List lists all ComponentVersions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ComponentVersion, err error)
// Get retrieves the ComponentVersion from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ComponentVersion, error)
ComponentVersionListerExpansion
}
ComponentVersionLister helps list ComponentVersions. All objects returned here must be treated as read-only.
func NewComponentVersionLister ¶ added in v0.9.0
func NewComponentVersionLister(indexer cache.Indexer) ComponentVersionLister
NewComponentVersionLister returns a new ComponentVersionLister.
type ComponentVersionListerExpansion ¶ added in v0.9.0
type ComponentVersionListerExpansion interface{}
ComponentVersionListerExpansion allows custom methods to be added to ComponentVersionLister.
type ConfigConstraintLister ¶
type ConfigConstraintLister interface {
// List lists all ConfigConstraints in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ConfigConstraint, err error)
// Get retrieves the ConfigConstraint from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ConfigConstraint, error)
ConfigConstraintListerExpansion
}
ConfigConstraintLister helps list ConfigConstraints. All objects returned here must be treated as read-only.
func NewConfigConstraintLister ¶
func NewConfigConstraintLister(indexer cache.Indexer) ConfigConstraintLister
NewConfigConstraintLister returns a new ConfigConstraintLister.
type ConfigConstraintListerExpansion ¶
type ConfigConstraintListerExpansion interface{}
ConfigConstraintListerExpansion allows custom methods to be added to ConfigConstraintLister.
type OpsDefinitionLister ¶ added in v0.8.0
type OpsDefinitionLister interface {
// List lists all OpsDefinitions in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.OpsDefinition, err error)
// Get retrieves the OpsDefinition from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.OpsDefinition, error)
OpsDefinitionListerExpansion
}
OpsDefinitionLister helps list OpsDefinitions. All objects returned here must be treated as read-only.
func NewOpsDefinitionLister ¶ added in v0.8.0
func NewOpsDefinitionLister(indexer cache.Indexer) OpsDefinitionLister
NewOpsDefinitionLister returns a new OpsDefinitionLister.
type OpsDefinitionListerExpansion ¶ added in v0.8.0
type OpsDefinitionListerExpansion interface{}
OpsDefinitionListerExpansion allows custom methods to be added to OpsDefinitionLister.
type OpsRequestLister ¶
type OpsRequestLister interface {
// List lists all OpsRequests in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.OpsRequest, err error)
// OpsRequests returns an object that can list and get OpsRequests.
OpsRequests(namespace string) OpsRequestNamespaceLister
OpsRequestListerExpansion
}
OpsRequestLister helps list OpsRequests. All objects returned here must be treated as read-only.
func NewOpsRequestLister ¶
func NewOpsRequestLister(indexer cache.Indexer) OpsRequestLister
NewOpsRequestLister returns a new OpsRequestLister.
type OpsRequestListerExpansion ¶
type OpsRequestListerExpansion interface{}
OpsRequestListerExpansion allows custom methods to be added to OpsRequestLister.
type OpsRequestNamespaceLister ¶
type OpsRequestNamespaceLister interface {
// List lists all OpsRequests in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.OpsRequest, err error)
// Get retrieves the OpsRequest from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.OpsRequest, error)
OpsRequestNamespaceListerExpansion
}
OpsRequestNamespaceLister helps list and get OpsRequests. All objects returned here must be treated as read-only.
type OpsRequestNamespaceListerExpansion ¶
type OpsRequestNamespaceListerExpansion interface{}
OpsRequestNamespaceListerExpansion allows custom methods to be added to OpsRequestNamespaceLister.
type ServiceDescriptorLister ¶ added in v0.7.0
type ServiceDescriptorLister interface {
// List lists all ServiceDescriptors in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceDescriptor, err error)
// ServiceDescriptors returns an object that can list and get ServiceDescriptors.
ServiceDescriptors(namespace string) ServiceDescriptorNamespaceLister
ServiceDescriptorListerExpansion
}
ServiceDescriptorLister helps list ServiceDescriptors. All objects returned here must be treated as read-only.
func NewServiceDescriptorLister ¶ added in v0.7.0
func NewServiceDescriptorLister(indexer cache.Indexer) ServiceDescriptorLister
NewServiceDescriptorLister returns a new ServiceDescriptorLister.
type ServiceDescriptorListerExpansion ¶ added in v0.7.0
type ServiceDescriptorListerExpansion interface{}
ServiceDescriptorListerExpansion allows custom methods to be added to ServiceDescriptorLister.
type ServiceDescriptorNamespaceLister ¶ added in v0.7.0
type ServiceDescriptorNamespaceLister interface {
// List lists all ServiceDescriptors in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.ServiceDescriptor, err error)
// Get retrieves the ServiceDescriptor from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.ServiceDescriptor, error)
ServiceDescriptorNamespaceListerExpansion
}
ServiceDescriptorNamespaceLister helps list and get ServiceDescriptors. All objects returned here must be treated as read-only.
type ServiceDescriptorNamespaceListerExpansion ¶ added in v0.7.0
type ServiceDescriptorNamespaceListerExpansion interface{}
ServiceDescriptorNamespaceListerExpansion allows custom methods to be added to ServiceDescriptorNamespaceLister.