Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ConfigConstraintLister ¶
type ConfigConstraintLister interface {
// List lists all ConfigConstraints in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1beta1.ConfigConstraint, err error)
// Get retrieves the ConfigConstraint from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1beta1.ConfigConstraint, error)
ConfigConstraintListerExpansion
}
ConfigConstraintLister helps list ConfigConstraints. All objects returned here must be treated as read-only.
func NewConfigConstraintLister ¶
func NewConfigConstraintLister(indexer cache.Indexer) ConfigConstraintLister
NewConfigConstraintLister returns a new ConfigConstraintLister.
type ConfigConstraintListerExpansion ¶
type ConfigConstraintListerExpansion interface{}
ConfigConstraintListerExpansion allows custom methods to be added to ConfigConstraintLister.
Click to show internal directories.
Click to hide internal directories.