Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddonLister ¶
type AddonLister interface {
// List lists all Addons in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Addon, err error)
// Get retrieves the Addon from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Addon, error)
AddonListerExpansion
}
AddonLister helps list Addons. All objects returned here must be treated as read-only.
func NewAddonLister ¶
func NewAddonLister(indexer cache.Indexer) AddonLister
NewAddonLister returns a new AddonLister.
type AddonListerExpansion ¶
type AddonListerExpansion interface{}
AddonListerExpansion allows custom methods to be added to AddonLister.
Click to show internal directories.
Click to hide internal directories.